@@ -10,7 +10,7 @@ use crate::ui::{CsvTable, CsvTableState, FinderState};
 
 extern crate csv as sushi_csv;
 
-use anyhow::{Context, Result, bail};
+use anyhow::{bail, Context, Result};
 use clap::Parser;
 use std::convert::TryInto;
 use std::fs::File;
@@ -27,23 +27,21 @@ fn get_offsets_to_make_visible(
     rows_view: &view::RowsView,
     csv_table_state: &CsvTableState,
 ) -> (Option<u64>, Option<u64>) {
-    let new_rows_offset;
     // TODO: row_index() should probably be u64
-    if rows_view.in_view(found_record.row_index() as u64) {
-        new_rows_offset = None;
+    let new_rows_offset = if rows_view.in_view(found_record.row_index() as u64) {
+        None
     } else {
-        new_rows_offset = Some(found_record.row_index() as u64);
-    }
+        Some(found_record.row_index() as u64)
+    };
 
-    let new_cols_offset;
     let cols_offset = csv_table_state.cols_offset;
     let last_rendered_col = cols_offset.saturating_add(csv_table_state.num_cols_rendered);
     let column_index = found_record.first_column() as u64;
-    if column_index >= cols_offset && column_index < last_rendered_col {
-        new_cols_offset = None;
+    let new_cols_offset = if column_index >= cols_offset && column_index < last_rendered_col {
+        None
     } else {
-        new_cols_offset = Some(column_index)
-    }
+        Some(column_index)
+    };
 
     (new_rows_offset, new_cols_offset)
 }
@@ -54,7 +52,7 @@ fn scroll_to_found_record(
     csv_table_state: &mut CsvTableState,
 ) {
     let (new_rows_offset, new_cols_offset) =
-        get_offsets_to_make_visible(found_record.clone(), rows_view, csv_table_state);
+        get_offsets_to_make_visible(found_record, rows_view, csv_table_state);
 
     if let Some(rows_offset) = new_rows_offset {
         rows_view.set_rows_from(rows_offset).unwrap();
@@ -67,31 +65,40 @@ fn scroll_to_found_record(
 }
 
 struct SeekableFile {
-    filename: String,
+    filename: Option<String>,
     inner_file: Option<NamedTempFile>,
 }
 
 impl SeekableFile {
-    fn new(filename: &str) -> Result<SeekableFile> {
-        let mut f = File::open(filename).context(format!("Failed to open file: {}", filename))?;
-
+    fn new(maybe_filename: &Option<String>) -> Result<SeekableFile> {
         let mut inner_file = NamedTempFile::new()?;
         let inner_file_res;
 
-        // If not seekable, it most likely is due to process substitution using
-        // pipe - write out to a temp file to make it seekable
-        if f.seek(SeekFrom::Start(0)).is_err() {
-            let mut buffer: Vec<u8> = vec![];
-            // TODO: could have read by chunks, yolo for now
-            f.read_to_end(&mut buffer)?;
-            inner_file.write(&buffer)?;
-            inner_file_res = Some(inner_file);
+        if let Some(filename) = maybe_filename {
+            let err = format!("Failed to open file: {}", filename);
+            let mut f = File::open(filename).context(err)?;
+            // If not seekable, it most likely is due to process substitution using
+            // pipe - write out to a temp file to make it seekable
+            if f.seek(SeekFrom::Start(0)).is_err() {
+                let mut buffer: Vec<u8> = vec![];
+                // TODO: could have read by chunks, yolo for now
+                f.read_to_end(&mut buffer)?;
+                inner_file.write_all(&buffer)?;
+                inner_file_res = Some(inner_file);
+            } else {
+                inner_file_res = None;
+            }
         } else {
-            inner_file_res = None;
+            // Handle input from stdin
+            let mut stdin = std::io::stdin();
+            let mut buffer: Vec<u8> = vec![];
+            stdin.read_to_end(&mut buffer)?;
+            inner_file.write_all(&buffer)?;
+            inner_file_res = Some(inner_file);
         }
 
         Ok(SeekableFile {
-            filename: filename.to_string(),
+            filename: maybe_filename.clone(),
             inner_file: inner_file_res,
         })
     }
@@ -100,7 +107,8 @@ impl SeekableFile {
         if let Some(f) = &self.inner_file {
             f.path().to_str().unwrap()
         } else {
-            self.filename.as_str()
+            // If data is from stdin, then inner_file must be there
+            self.filename.as_ref().unwrap()
         }
     }
 }
@@ -108,7 +116,7 @@ impl SeekableFile {
 #[derive(Parser, Debug)]
 struct Args {
     /// CSV filename
-    filename: String,
+    filename: Option<String>,
 
     /// Delimiter character (comma by default)
     #[clap(short, long)]
@@ -124,7 +132,10 @@ fn parse_delimiter(args: &Args) -> Result<Option<u8>> {
         let mut chars = s.chars();
         let c = chars.next().context("Delimiter should not be empty")?;
         if !c.is_ascii() {
-            bail!("Delimiter should be within the ASCII range: {} is too fancy", c);
+            bail!(
+                "Delimiter should be within the ASCII range: {} is too fancy",
+                c
+            );
         }
         if chars.next().is_some() {
             bail!("Delimiter should be exactly one character, got {}", s);
@@ -141,7 +152,7 @@ fn run_csvlens() -> Result<()> {
     let show_stats = args.debug;
     let delimiter = parse_delimiter(&args)?;
 
-    let file = SeekableFile::new(args.filename.as_str())?;
+    let file = SeekableFile::new(&args.filename)?;
     let filename = file.filename();
 
     // Some lines are reserved for plotting headers (3 lines for headers + 2 lines for status bar)
@@ -168,7 +179,7 @@ fn run_csvlens() -> Result<()> {
     let mut terminal = Terminal::new(backend).unwrap();
 
     let mut input_handler = InputHandler::new();
-    let mut csv_table_state = CsvTableState::new(filename.to_string(), headers.len());
+    let mut csv_table_state = CsvTableState::new(args.filename, headers.len());
 
     let mut finder: Option<find::Finder> = None;
     let mut first_found_scrolled = false;
@@ -308,7 +319,7 @@ fn run_csvlens() -> Result<()> {
 
 fn main() {
     if let Err(e) = run_csvlens() {
-        println!("{}", e.to_string());
+        println!("{}", e);
         std::process::exit(1);
     }
 }
